import pickle 

def load(path):
    try:
        file = open(path, "rb")
        tuturu = pickle.load(file)
        file.close()
        return tuturu
    except Exception:
        return None
        
def dump(var, path):
    try:
        file = open(path, "wb")
        pickle.dump(var, file)
        file.close()
        return True
    except Exception:
        return False

def main():
    print("hello main") 

if __name__ == "__main__":
    main()



from distutils.core import setup
setup(
  name = 'tuturu2',
  packages = ['tuturu2'], # this must be the same as the name above
  version = '0.6',
  description = 'A module to simplify the well know module named pickle.',
  author = 'Pickle',
  author_email = 'pickle@gmail.com',
  url = 'http://marco213.com', # use the URL to the github repo
  keywords = ['pickle', 'tuturu'], # arbitrary keywords
  classifiers = [],
)
